//--------------------------------------------------------------
// File     : main.c
// Datum    : 09.09.2014
// Version  : 1.0
// Autor    : AJ
// CPU      : STM32F4
// IDE      : CooCox CoIDE 1.7.0
// Module   : CMSIS_BOOT, M4_CMSIS_CORE
// Hinweis  : Diese zwei Files muessen auf 8MHz stehen
//              "cmsis_boot/stm32f4xx.h"
//              "cmsis_boot/system_stm32f4xx.c"
//--------------------------------------------------------------
// Funktion : 
// Programm um 4 Funktionstasten einzulesen
// mit zwei Tasten wird ein Wert fr eine Quelle hoch oder
// runter gezhlt.

// Die ausgewhlten Texte werden im Kreis gescrollt (hartes scrollen!!)
// Anzeige der ausgewhlten Quelle ber Farbumschlag
//
//
// mit zwei anderen Tasten wird ein Wert fr Volume hoch oder
// runter gezhlt.
// Volume kann auch ber einen Schieber im Bar-Graph verndert werden
//
// Funktionen in axel.c ausgelagert
// Funktion LCD_Draw_Bar_graph in axel.c verschoben
//
// Von der Beispiel Lib. von Uwe wurden bei den Funktionen 
// UB_Font_DrawString, UB_Font_DrawString32 
// die Eingnge x und y getauscht, da die Auswertung beim Format Landscape
// falsch herum war.
//--------------------------------------------------------------

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "stm32f4xx.h"
#include "stm32f4xx_gpio.h"
#include "stm32f4xx_rcc.h"
#include "stm32f4xx_tim.h"
#include "misc.h"

#include "main.h"
#include "stm32_ub_lcd_ssd1289.h"
#include "stm32_ub_font.h"
#include "stm32_ub_touch_ads7843.h"

#define  LCD_SSD1289_PAUSE3   500000
#define  RGB_dunkel_grau    21130



// ********************************************************************************** 
//  globale Variablen 
// **********************************************************************************  

   	char buf[20];

	unsigned char  source_p_timer=0;
	unsigned char  source_m_timer=0;
	unsigned char  volume_p_timer=0;
	unsigned char  volume_m_timer=0;

	unsigned char  scroll_up=0;
	unsigned char  scroll_down=0;


//	unsigned char  fkt5_timer=0;
//	unsigned char  fkt6_timer=0;


// ********************************************************************************** 


//***** Function Prototype **************************************************

void P_LCD1289_Delay(volatile uint32_t nCount);
void UB_Graphic_DrawPixel (int16_t xpos, int16_t ypos, uint16_t color);
void UB_Graphic_DrawLine(int16_t x1, int16_t y1, int16_t x2, int16_t y2, uint16_t color);
void NVIC_INIT_EXAMPLE(uint16_t IRQ);
void tohex4(unsigned long h1);
void tohex3(unsigned long h1);
void tohex2m(unsigned long h1);
void tohex2(unsigned long h1);
void tohex5(unsigned long h1);
unsigned int funkt75_30 (uint16_t x, uint16_t y, uint16_t fktouch_x, uint16_t fktouch_y);
unsigned int funkt50_50 (uint16_t x, uint16_t y, uint16_t fktouch_x, uint16_t fktouch_y);
void LCD_Draw_Bar_graph(uint16_t xpos, uint16_t ypos, uint16_t ymax, uint16_t wert);
void LCD_line(uint16_t xpos, uint16_t ypos , uint16_t coll );

// ********************************************************************************** 

// **********************************************************************************
void TIMER_INIT_EXAMPLE(void)
{
	TIM_TimeBaseInitTypeDef TIM_TimeBaseInitStructure;
////////// Timer 2 /////////////////////////////////////////////////
	// Der Timer wird mit 84MHz getaktet (APB1 Domain mit 42MHz X2 siehe Seite 85 im Ref.Man.)
	RCC_APB1PeriphClockCmd(RCC_APB1Periph_TIM2, ENABLE);
	// Time Base initialisieren
	TIM_TimeBaseInitStructure.TIM_ClockDivision = TIM_CKD_DIV1;
	TIM_TimeBaseInitStructure.TIM_CounterMode = TIM_CounterMode_Up;
	TIM_TimeBaseInitStructure.TIM_Prescaler = 100-1; // 	84MHz / 100 = 840 kHz nach Prescaler
	TIM_TimeBaseInitStructure.TIM_Period = 84 - 1;  //	840khz / 84 = 10.000 Hz endgltige Updaterate des Timers
	TIM_TimeBaseInitStructure.TIM_RepetitionCounter = 0;
	TIM_TimeBaseInit(TIM2, &TIM_TimeBaseInitStructure);

	// Interrupt enable fr Update
	TIM_ITConfig(TIM2,TIM_IT_Update,ENABLE);

	// um den Timer loslaufen zu lassen
	TIM_Cmd(TIM2,ENABLE);

	/////////////////////////////////////////////////////////////////////
///////// Timer 3 ///////////////////////////////////////////////////
	// Der Timer wird mit 84MHz getaktet (APB1 Domain mit 42MHz X2 siehe Seite 85 im Ref.Man.)
	RCC_APB1PeriphClockCmd(RCC_APB1Periph_TIM3, ENABLE);
	// Time Base initialisieren
	TIM_TimeBaseInitStructure.TIM_ClockDivision = TIM_CKD_DIV1;
	TIM_TimeBaseInitStructure.TIM_CounterMode = TIM_CounterMode_Up;
	TIM_TimeBaseInitStructure.TIM_Prescaler = 1000-1; // 	84MHz / 1000 = 84 kHz nach Prescaler
	TIM_TimeBaseInitStructure.TIM_Period = 8400 - 1;  //	84khz / 840 = 10 Hz endgltige Updaterate des Timers
	TIM_TimeBaseInitStructure.TIM_RepetitionCounter = 0;
	TIM_TimeBaseInit(TIM3, &TIM_TimeBaseInitStructure);

	// Interrupt enable fr Update
	TIM_ITConfig(TIM3,TIM_IT_Update,ENABLE);

	// um den Timer loslaufen zu lassen
	TIM_Cmd(TIM3,ENABLE);
}

// ********************************************************************************** 
void NVIC_INIT_EXAMPLE(uint16_t IRQ)
	{
		NVIC_InitTypeDef NVIC_InitStructure;

		NVIC_InitStructure.NVIC_IRQChannel = IRQ;
		NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;
		NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 0; // Die Prioritt --> kleine Zahlen = hohe Prioritt
		NVIC_InitStructure.NVIC_IRQChannelSubPriority = 0;
		NVIC_Init(&NVIC_InitStructure);
	}
// ********************************************************************************** 



// **********************************************************************************
//  Timer 2 Interrupt Routine 10.000Hz oder alle 100s
// **********************************************************************************
void TIM2_IRQHandler(void)
	{
	while( (TIM2->SR & (1<<0)) > 0 ) TIM2->SR &= ~(1<<0); // clear UIF flag


	}
// ********************************************************************************** 

// **********************************************************************************
//  Timer 3 Interrupt Routine 10Hz oder alle 100ms
// ********************************************************************************** 
void TIM3_IRQHandler(void)
	{
	while( (TIM3->SR & (1<<0)) > 0 ) TIM3->SR &= ~(1<<0); // clear UIF flag
	
	if (source_p_timer) source_p_timer--;
	if (source_m_timer) source_m_timer--;
	if (volume_p_timer) volume_p_timer--;
	if (volume_m_timer) volume_m_timer--;

	if (scroll_up)  scroll_up--;
	if (scroll_down) scroll_down--;

	}

// ********************************************************************************** 


int main(void)
{
// ********************************************************************************** 
//  Variablen in main
// **********************************************************************************    
	uint16_t n=0;			// Programmzyklenzhler
	uint16_t touch_x=0;		// Touch Koordinate X
	uint16_t touch_y=0;		// Touch Koordinate Y

	uint16_t source_p=0;
	uint16_t source_m=0;
	uint16_t volume_p=0;
	uint16_t volume_m=0;

	uint16_t volume=25;
	int source=3;


const char options[17][10] = {
	{" Phono  "}, 	// Sorce = 1
	{"   CD   "}, 	// Sorce = 2
	{"  Tape  "}, 	// Sorce = 3
	{" Tuner  "}, 	// Sorce = 4
	{" SPDIF  "}, 	// Sorce = 5
	{" Analog "}, 	// Sorce = 6
	{"Optisch "}, 	// Sorce = 7

	{" Phono  "}, 	// Sorce = 1
	{"   CD   "}, 	// Sorce = 2
	{"  Tape  "}, 	// Sorce = 3
	{" Tuner  "}, 	// Sorce = 4
	{" SPDIF  "}, 	// Sorce = 5
	{" Analog "}, 	// Sorce = 6
	{"Optisch "}, 	// Sorce = 7

	{"xxxxxxx"},	// ungltige Auswahl	
	{"xxxxxxx"},	// ungltige Auswahl	
	{"xxxxxx"},};	// ungltige Auswahl	


char buf1[10]= {"  "};	// Ausgabepuffer 1. Textzeile
char buf2[10]= {"  "};	// Ausgabepuffer 2. Textzeile
char buf3[10]= {"  "};	// Ausgabepuffer 3. Textzeile
char buf4[10]= {"  "};	// Ausgabepuffer 4. Textzeile
char buf5[10]= {"  "};	// Ausgabepuffer 5. Textzeile
char buf6[10]= {"  "};	// Ausgabepuffer 6. Textzeile
char buf7[10]= {"  "};	// Ausgabepuffer 7. Textzeile

// ********************************************************************************** 

 
// Initialisierung ******************************************************************

SystemInit(); 				// Quarz Einstellungen aktivieren
TIMER_INIT_EXAMPLE();			// Timer initialisieren
NVIC_INIT_EXAMPLE(TIM2_IRQn);		// Timer 2 Interrupt initialisieren
NVIC_INIT_EXAMPLE(TIM3_IRQn);		// Timer 3 Interrupt initialisieren

P_LCD1289_Delay(LCD_SSD1289_PAUSE3);
P_LCD1289_Delay(LCD_SSD1289_PAUSE3);
P_LCD1289_Delay(LCD_SSD1289_PAUSE3);
P_LCD1289_Delay(LCD_SSD1289_PAUSE3);

UB_Touch_Init();  			// init vom Touch

UB_LCD_Init(); 				// init vom LCD

UB_LCD_SetMode(LANDSCAPE);		// LCD auf Querformat stellen
  
UB_LCD_FillScreen(RGB_COL_BLACK); 	// Bildschirm lschen

// ************************************************************************************ 


// ************************************************************************************ 
while(1)
  {



// Touch Koordinaten einlesen ********************************************************
if(Touch_Data.status==TOUCH_PRESSED) {	// Touch Koordinaten einlesen
	  // wenn Touch gedrckt ist,
	  touch_y= Touch_Data.pos.xp;
	  touch_x= Touch_Data.pos.yp;
}
else {touch_y=0; touch_x=0;}		// wenn der Touch nicht bettigt ist, dann die Werte auf 0 setzen




// Buffer fr Stringausgebe lschen
buf[0]=0x00; // ""
buf[1]=0x00; // ""
buf[2]=0x00; // ""
buf[3]=0x00; // ""
buf[4]=0x00; // ""




// Funktionstasten 1 bis 4 ************************************************************
source_p=funkt75_30(touch_x,touch_y, 30 ,5);	// actueller x , actueller y Wert, Anfang x , Anfang y
source_m=funkt75_30(touch_x,touch_y, 30 ,205);	// actueller x , actueller y Wert, Anfang x , Anfang y
volume_m=funkt75_30(touch_x,touch_y, 190 ,5);	// actueller x , actueller y Wert, Anfang x , Anfang y
volume_p=funkt75_30(touch_x,touch_y, 190 ,205);	// actueller x , actueller y Wert, Anfang x , Anfang y
// ************************************************************************************ 





// ************************************************************************************ 
// Ausgabe Volume *******************************
if ((touch_x>=150) && (touch_x<=190) && (touch_y>=40)) volume=(touch_y-40)/3;if (volume<=0)volume =0;
if (volume>=64)volume =64;

if ((volume_m==1) & (volume_m_timer==0) & (volume<=63)) {volume--; volume_m_timer=3;}
if ((volume_p==1) & (volume_p_timer==0) & (volume>=1))    {volume++; volume_p_timer=3;}

LCD_Draw_Bar_graph(170, 30, 200,volume*3);// x,y,ymax,wert

		
buf[3]=0x00; // ""
buf[4]=0x00; // ""

tohex2(volume);
UB_Font_DrawString32(220,50,buf,&Arial_18x27,RGB_COL_GREEN,RGB_COL_BLACK);

// ************************************************************************************ 



// ************************************************************************************ 
// Ausgabe Source *******************************


if ((source_p ==1) & (source_p_timer==0) & (source<=7)) {source++; source_p_timer=3; scroll_down=10;}
if ((source_m ==1) & (source_m_timer==0) & (source>=0))    {source--; source_m_timer=3; scroll_up=10;}

if (source==8) source=1; 	// im Kreis scrollen
if (source==0) source=7; 	// im Kreis scrollen 



// Ausgabe auf dem LCD ****************************************************************
// es werden 7 Schreib-Buffer mit den Texten gem
// initialisierung des Array beschrieben

int i=0;

for (i=0; i<8; i++)
	{
	buf1[i] = options[source+4][i];
	buf2[i] = options[source+5][i];
	buf3[i] = options[source+6][i];

	buf4[i] = options[source][i];

	buf5[i] = options[source+1][i];
	buf6[i] = options[source+2][i];
	buf7[i] = options[source+3][i];
	}	
if ((scroll_down==0) & (scroll_up==0)){
UB_Font_DrawString(30,200,"       ",&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 0. Zeile
UB_Font_DrawString(30,180,buf7,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 1. Zeile
UB_Font_DrawString(30,160,buf6,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 2. Zeile
UB_Font_DrawString(30,140,buf5,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 3. Zeile

UB_Font_DrawString32(1,105,buf4,&Arial_18x27,RGB_COL_YELLOW,RGB_COL_BLACK); // 4. Zeile

UB_Font_DrawString(30,80,buf3,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 5. Zeile
UB_Font_DrawString(30,60,buf2,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 6. Zeile
UB_Font_DrawString(30,40,buf1,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 7. Zeile
UB_Font_DrawString(30,20,"       ",&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 8. Zeile





}
else {
if (scroll_down==9)	{
	UB_Font_DrawString(30,178,buf7,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 1. Zeile
	UB_Font_DrawString(30,158,buf6,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 2. Zeile
	UB_Font_DrawString(30,138,buf5,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 3. Zeile

	UB_Font_DrawString32(1,103,buf4,&Arial_18x27,RGB_COL_YELLOW,RGB_COL_BLACK); // 4. Zeile

	UB_Font_DrawString(30,78,buf3,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 5. Zeile
	UB_Font_DrawString(30,58,buf2,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 6. Zeile
	UB_Font_DrawString(30,38,buf1,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 7. Zeile

	LCD_line(2,180,RGB_COL_BLACK); // Waagerechte Linie
	LCD_line(2,160,RGB_COL_BLACK); // Waagerechte Linie
	LCD_line(2,140,RGB_COL_BLACK); // Waagerechte Linie
	LCD_line(2,105,RGB_COL_BLACK); // Waagerechte Linie
	LCD_line(2,80,RGB_COL_BLACK); // Waagerechte Linie
	LCD_line(2,60,RGB_COL_BLACK); // Waagerechte Linie
	LCD_line(2,40,RGB_COL_BLACK); // Waagerechte Linie

}
if (scroll_down==8)	{
	UB_Font_DrawString(30,176,buf7,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 1. Zeile
	UB_Font_DrawString(30,156,buf6,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 2. Zeile
	UB_Font_DrawString(30,136,buf5,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 3. Zeile

	UB_Font_DrawString32(1,101,buf4,&Arial_18x27,RGB_COL_YELLOW,RGB_COL_BLACK); // 4. Zeile

	UB_Font_DrawString(30,76,buf3,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 5. Zeile
	UB_Font_DrawString(30,56,buf2,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 6. Zeile
	UB_Font_DrawString(30,36,buf1,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 7. Zeile
}
if (scroll_down==7)	{
	UB_Font_DrawString(30,174,buf7,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 1. Zeile
	UB_Font_DrawString(30,154,buf6,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 2. Zeile
	UB_Font_DrawString(30,134,buf5,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 3. Zeile

	UB_Font_DrawString32(1,99,buf4,&Arial_18x27,RGB_COL_YELLOW,RGB_COL_BLACK); // 4. Zeile

	UB_Font_DrawString(30,74,buf3,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 5. Zeile
	UB_Font_DrawString(30,54,buf2,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 6. Zeile
	UB_Font_DrawString(30,34,buf1,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 7. Zeile
}
if (scroll_down==6)	{
	UB_Font_DrawString(30,172,buf7,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 1. Zeile
	UB_Font_DrawString(30,152,buf6,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 2. Zeile
	UB_Font_DrawString(30,132,buf5,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 3. Zeile

	UB_Font_DrawString32(1,97,buf4,&Arial_18x27,RGB_COL_YELLOW,RGB_COL_BLACK); // 4. Zeile

	UB_Font_DrawString(30,72,buf3,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 5. Zeile
	UB_Font_DrawString(30,52,buf2,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 6. Zeile
	UB_Font_DrawString(30,32,buf1,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 7. Zeile
}
if (scroll_down==5)	{
	UB_Font_DrawString(30,170,buf7,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 1. Zeile
	UB_Font_DrawString(30,150,buf6,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 2. Zeile
	UB_Font_DrawString(30,130,buf5,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 3. Zeile

	UB_Font_DrawString32(1,95,buf4,&Arial_18x27,RGB_COL_YELLOW,RGB_COL_BLACK); // 4. Zeile

	UB_Font_DrawString(30,70,buf3,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 5. Zeile
	UB_Font_DrawString(30,50,buf2,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 6. Zeile
	UB_Font_DrawString(30,30,buf1,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 7. Zeile
}
if (scroll_down==4)	{
	UB_Font_DrawString(30,168,buf7,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 1. Zeile
	UB_Font_DrawString(30,148,buf6,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 2. Zeile
	UB_Font_DrawString(30,128,buf5,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 3. Zeile

	UB_Font_DrawString32(1,93,buf4,&Arial_18x27,RGB_COL_YELLOW,RGB_COL_BLACK); // 4. Zeile

	UB_Font_DrawString(30,68,buf3,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 5. Zeile
	UB_Font_DrawString(30,48,buf2,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 6. Zeile
	UB_Font_DrawString(30,28,buf1,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 7. Zeile
}
if (scroll_down==3)	{
	UB_Font_DrawString(30,166,buf7,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 1. Zeile
	UB_Font_DrawString(30,146,buf6,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 2. Zeile
	UB_Font_DrawString(30,146,buf5,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 3. Zeile

	UB_Font_DrawString32(1,91,buf4,&Arial_18x27,RGB_COL_YELLOW,RGB_COL_BLACK); // 4. Zeile

	UB_Font_DrawString(30,66,buf3,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 5. Zeile
	UB_Font_DrawString(30,46,buf2,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 6. Zeile
	UB_Font_DrawString(30,26,buf1,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 7. Zeile
}
if (scroll_down==2)	{
	UB_Font_DrawString(30,164,buf7,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 1. Zeile
	UB_Font_DrawString(30,144,buf6,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 2. Zeile
	UB_Font_DrawString(30,124,buf5,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 3. Zeile

	UB_Font_DrawString32(1,89,buf4,&Arial_18x27,RGB_COL_YELLOW,RGB_COL_BLACK); // 4. Zeile

	UB_Font_DrawString(30,64,buf3,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 5. Zeile
	UB_Font_DrawString(30,44,buf2,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 6. Zeile
	UB_Font_DrawString(30,24,buf1,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 7. Zeile
}
if (scroll_down==1)	{
	UB_Font_DrawString(30,162,buf7,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 1. Zeile
	UB_Font_DrawString(30,142,buf6,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 2. Zeile
	UB_Font_DrawString(30,122,buf5,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 3. Zeile

	UB_Font_DrawString32(1,87,buf4,&Arial_18x27,RGB_COL_YELLOW,RGB_COL_BLACK); // 4. Zeile

	UB_Font_DrawString(30,62,buf3,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 5. Zeile
	UB_Font_DrawString(30,42,buf2,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 6. Zeile
	UB_Font_DrawString(30,22,buf1,&Arial_11x18,RGB_COL_BLUE,RGB_COL_BLACK); // 7. Zeile
}

}	// ende else




// ************************************************************************************ 



// Ausgabe Programmzyklenzhler unten rechts in der Ecke *******************************
if (n< 10000)	n++; else n=0;	// Programmzyklenzhler zur Bestimmung der Zykluszeit
				// Spielerei zur Einschtzung wie lange die Textausgaben dauern

tohex5(n);
UB_Font_DrawString(250,120,"p-Zyk",&Arial_11x18,RGB_dunkel_grau,RGB_COL_BLACK);
UB_Font_DrawString(240,100,buf,&Arial_11x18,RGB_dunkel_grau,RGB_COL_BLACK);

// Buffer fr Stringausgebe lschen
buf[0]=0x00; // ""
buf[1]=0x00; // ""
buf[2]=0x00; // ""
buf[3]=0x00; // ""
buf[4]=0x00; // ""


// Ausgabe Touch Koordinaten oben rechts in der Ecke **********************************
UB_Font_DrawString(250,180,"Touch",&Arial_11x18,RGB_dunkel_grau,RGB_COL_BLACK);

UB_Font_DrawString(250,160,"Y= ",&Arial_11x18,RGB_dunkel_grau,RGB_COL_BLACK);
tohex3(touch_y);
UB_Font_DrawString(280,160,buf,&Arial_11x18,RGB_dunkel_grau,RGB_COL_BLACK);

UB_Font_DrawString(250,140,"x= ",&Arial_11x18,RGB_dunkel_grau,RGB_COL_BLACK);
tohex3(touch_x);
UB_Font_DrawString(280,140,buf,&Arial_11x18,RGB_dunkel_grau,RGB_COL_BLACK);

tohex3(scroll_up);
UB_Font_DrawString(210,140,buf,&Arial_11x18,RGB_dunkel_grau,RGB_COL_BLACK);

tohex3(scroll_down);
UB_Font_DrawString(210,160,buf,&Arial_11x18,RGB_dunkel_grau,RGB_COL_BLACK);


LCD_line(2,40,RGB_COL_BLUE); // Waagerechte Linie




// ************************************************************************************







  }	// end While(1)
// ************************************************************************************* 
}	// end main
// ************************************************************************************* 
// ************************************************************************************* 
// ************************************************************************************* 
// ************************************************************************************* 







