//--------------------------------------------------------------
// File     : main.c
// Datum    : 09.09.2014
// Version  : 1.0
// Autor    : AJ
// CPU      : STM32F4
// IDE      : CooCox CoIDE 1.7.0
// Module   : CMSIS_BOOT, M4_CMSIS_CORE
// Hinweis  : Diese zwei Files muessen auf 8MHz stehen
//              "cmsis_boot/stm32f4xx.h"
//              "cmsis_boot/system_stm32f4xx.c"
//--------------------------------------------------------------
// Funktion : 
// Programm um 4 Funktionstasten einzulesen
// mit zwei Tasten wird ein Wert fr eine Quelle hoch oder
// runter gezhlt.

// Die ausgewhlten Texte werden im Kreis gescrollt (hartes scrollen!!)
// Anzeige der ausgewhlten Quelle ber Farbumschlag
//
//
// mit zwei anderen Tasten wird ein Wert fr Volume hoch oder
// runter gezhlt.
// Volume kann auch ber einen Schieber im Bar-Graph verndert werden
//
// Funktionen in axel.c ausgelagert
// Funktion LCD_Draw_Bar_graph in axel.c verschoben
//
// Von der Beispiel Lib. von Uwe wurden bei den Funktionen 
// UB_Font_DrawString, UB_Font_DrawString32 
// die Eingnge x und y getauscht, da die Auswertung beim Format Landscape
// falsch herum war.
//--------------------------------------------------------------

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "stm32f4xx.h"
#include "stm32f4xx_gpio.h"
#include "stm32f4xx_rcc.h"
#include "stm32f4xx_tim.h"
#include "misc.h"

#include "main.h"
#include "stm32_ub_lcd_ssd1289.h"
#include "stm32_ub_font.h"
#include "stm32_ub_touch_ads7843.h"

#define  LCD_SSD1289_PAUSE3   500000
#define  RGB_dunkel_grau    21130



// ********************************************************************************** 
//  globale Variablen 
// **********************************************************************************  

   	char buf[20];

	unsigned char  s_p_timer=0;
	unsigned char  s_m_timer=0;
	unsigned char  v_p_timer=0;
	unsigned char  v_m_timer=0;




//	unsigned char  fkt5_timer=0;
//	unsigned char  fkt6_timer=0;


// ********************************************************************************** 


//***** Function Prototype **************************************************

void P_LCD1289_Delay(volatile uint32_t nCount);
void UB_Graphic_DrawPixel (int16_t xpos, int16_t ypos, uint16_t color);
void UB_Graphic_DrawLine(int16_t x1, int16_t y1, int16_t x2, int16_t y2, uint16_t color);
void NVIC_INIT_EXAMPLE(uint16_t IRQ);
void tohex4(unsigned long h1);
void tohex3(unsigned long h1);
void tohex2m(unsigned long h1);
void tohex2(unsigned long h1);
void tohex5(unsigned long h1);
unsigned int funkt75_30 (uint16_t x, uint16_t y, uint16_t fktouch_x, uint16_t fktouch_y);
unsigned int funkt50_50 (uint16_t x, uint16_t y, uint16_t fktouch_x, uint16_t fktouch_y);
void LCD_Draw_Bar_graph(uint16_t xpos, uint16_t ypos, uint16_t ymax, uint16_t wert);
void LCD_line(uint16_t xpos, uint16_t ypos , uint16_t coll );

// ********************************************************************************** 

// **********************************************************************************
void TIMER_INIT_EXAMPLE(void)
{
	TIM_TimeBaseInitTypeDef TIM_TimeBaseInitStructure;
////////// Timer 2 /////////////////////////////////////////////////
	// Der Timer wird mit 84MHz getaktet (APB1 Domain mit 42MHz X2 siehe Seite 85 im Ref.Man.)
	RCC_APB1PeriphClockCmd(RCC_APB1Periph_TIM2, ENABLE);
	// Time Base initialisieren
	TIM_TimeBaseInitStructure.TIM_ClockDivision = TIM_CKD_DIV1;
	TIM_TimeBaseInitStructure.TIM_CounterMode = TIM_CounterMode_Up;
	TIM_TimeBaseInitStructure.TIM_Prescaler = 100-1; // 	84MHz / 100 = 840 kHz nach Prescaler
	TIM_TimeBaseInitStructure.TIM_Period = 84 - 1;  //	840khz / 84 = 10.000 Hz endgltige Updaterate des Timers
	TIM_TimeBaseInitStructure.TIM_RepetitionCounter = 0;
	TIM_TimeBaseInit(TIM2, &TIM_TimeBaseInitStructure);

	// Interrupt enable fr Update
	TIM_ITConfig(TIM2,TIM_IT_Update,ENABLE);

	// um den Timer loslaufen zu lassen
	TIM_Cmd(TIM2,ENABLE);

	/////////////////////////////////////////////////////////////////////
///////// Timer 3 ///////////////////////////////////////////////////
	// Der Timer wird mit 84MHz getaktet (APB1 Domain mit 42MHz X2 siehe Seite 85 im Ref.Man.)
	RCC_APB1PeriphClockCmd(RCC_APB1Periph_TIM3, ENABLE);
	// Time Base initialisieren
	TIM_TimeBaseInitStructure.TIM_ClockDivision = TIM_CKD_DIV1;
	TIM_TimeBaseInitStructure.TIM_CounterMode = TIM_CounterMode_Up;
	TIM_TimeBaseInitStructure.TIM_Prescaler = 500-1; // 	84MHz / 1000 = 84 kHz nach Prescaler
	TIM_TimeBaseInitStructure.TIM_Period = 8400 - 1;  //	84khz / 840 = 10 Hz endgltige Updaterate des Timers
	TIM_TimeBaseInitStructure.TIM_RepetitionCounter = 0;
	TIM_TimeBaseInit(TIM3, &TIM_TimeBaseInitStructure);

	// Interrupt enable fr Update
	TIM_ITConfig(TIM3,TIM_IT_Update,ENABLE);

	// um den Timer loslaufen zu lassen
	TIM_Cmd(TIM3,ENABLE);
}

// ********************************************************************************** 
void NVIC_INIT_EXAMPLE(uint16_t IRQ)
	{
		NVIC_InitTypeDef NVIC_InitStructure;

		NVIC_InitStructure.NVIC_IRQChannel = IRQ;
		NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;
		NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 0; // Die Prioritt --> kleine Zahlen = hohe Prioritt
		NVIC_InitStructure.NVIC_IRQChannelSubPriority = 0;
		NVIC_Init(&NVIC_InitStructure);
	}
// ********************************************************************************** 



// **********************************************************************************
//  Timer 2 Interrupt Routine 10.000Hz oder alle 100s
// **********************************************************************************
void TIM2_IRQHandler(void)
	{
	while( (TIM2->SR & (1<<0)) > 0 ) TIM2->SR &= ~(1<<0); // clear UIF flag


	}
// ********************************************************************************** 

// **********************************************************************************
//  Timer 3 Interrupt Routine 10Hz oder alle 100ms
// ********************************************************************************** 
void TIM3_IRQHandler(void)
	{
	while( (TIM3->SR & (1<<0)) > 0 ) TIM3->SR &= ~(1<<0); // clear UIF flag
	
	if (s_p_timer) s_p_timer--;
	if (s_m_timer) s_m_timer--;
	if (v_p_timer) v_p_timer--;
	if (v_m_timer) v_m_timer--;



	}

// ********************************************************************************** 


int main(void)
{
// ********************************************************************************** 
//  Variablen in main
// **********************************************************************************    
	uint16_t n=0;			// Programmzyklenzhler
	uint16_t touch_x=0;		// Touch Koordinate X
	uint16_t touch_y=0;		// Touch Koordinate Y

	uint16_t s_p=0;
	uint16_t s_m=0;
	uint16_t v_p=0;
	uint16_t v_m=0;





// ********************************************************************************** 

 
// Initialisierung ******************************************************************

SystemInit(); 				// Quarz Einstellungen aktivieren
TIMER_INIT_EXAMPLE();			// Timer initialisieren
NVIC_INIT_EXAMPLE(TIM2_IRQn);		// Timer 2 Interrupt initialisieren
NVIC_INIT_EXAMPLE(TIM3_IRQn);		// Timer 3 Interrupt initialisieren

P_LCD1289_Delay(LCD_SSD1289_PAUSE3);
P_LCD1289_Delay(LCD_SSD1289_PAUSE3);
P_LCD1289_Delay(LCD_SSD1289_PAUSE3);
P_LCD1289_Delay(LCD_SSD1289_PAUSE3);

UB_Touch_Init();  			// init vom Touch

UB_LCD_Init(); 				// init vom LCD

UB_LCD_SetMode(LANDSCAPE);		// LCD auf Querformat stellen
  
UB_LCD_FillScreen(RGB_COL_BLACK); 	// Bildschirm lschen

// ************************************************************************************ 


// ************************************************************************************ 
while(1)
  {



// Touch Koordinaten einlesen ********************************************************
if(Touch_Data.status==TOUCH_PRESSED) {	// Touch Koordinaten einlesen
	  // wenn Touch gedrckt ist,
	  touch_y= Touch_Data.pos.xp;
	  touch_x= Touch_Data.pos.yp;
}
else {touch_y=0; touch_x=0;}		// wenn der Touch nicht bettigt ist, dann die Werte auf 0 setzen




// Buffer fr Stringausgebe lschen
buf[0]=0x00; // ""
buf[1]=0x00; // ""
buf[2]=0x00; // ""
buf[3]=0x00; // ""
buf[4]=0x00; // ""




// Funktionstasten 1 bis 4 ************************************************************
s_p=funkt75_30(touch_x,touch_y, 30 ,5);	// actueller x , actueller y Wert, Anfang x , Anfang y
s_m=funkt75_30(touch_x,touch_y, 30 ,205);	// actueller x , actueller y Wert, Anfang x , Anfang y
v_m=funkt75_30(touch_x,touch_y, 190 ,5);	// actueller x , actueller y Wert, Anfang x , Anfang y
v_p=funkt75_30(touch_x,touch_y, 190 ,205);	// actueller x , actueller y Wert, Anfang x , Anfang y
// ************************************************************************************ 







// Ausgabe Programmzyklenzhler unten rechts in der Ecke *******************************
if (n< 10000)	n++; else n=0;	// Programmzyklenzhler zur Bestimmung der Zykluszeit
				// Spielerei zur Einschtzung wie lange die Textausgaben dauern

tohex5(n);
UB_Font_DrawString(250,120,"p-Zyk",&Arial_11x18,RGB_dunkel_grau,RGB_COL_BLACK);
UB_Font_DrawString(240,100,buf,&Arial_11x18,RGB_dunkel_grau,RGB_COL_BLACK);

// Buffer fr Stringausgebe lschen
buf[0]=0x00; // ""
buf[1]=0x00; // ""
buf[2]=0x00; // ""
buf[3]=0x00; // ""
buf[4]=0x00; // ""


// Ausgabe Touch Koordinaten oben rechts in der Ecke **********************************
UB_Font_DrawString(250,180,"Touch",&Arial_11x18,RGB_dunkel_grau,RGB_COL_BLACK);

UB_Font_DrawString(250,160,"Y= ",&Arial_11x18,RGB_dunkel_grau,RGB_COL_BLACK);
tohex3(touch_y);
UB_Font_DrawString(280,160,buf,&Arial_11x18,RGB_dunkel_grau,RGB_COL_BLACK);

UB_Font_DrawString(250,140,"x= ",&Arial_11x18,RGB_dunkel_grau,RGB_COL_BLACK);
tohex3(touch_x);
UB_Font_DrawString(280,140,buf,&Arial_11x18,RGB_dunkel_grau,RGB_COL_BLACK);



LCD_line(33,140,RGB_COL_BLUE); // Waagerechte Linie

UB_Graphic_DrawCircle(140, 120, 25, RGB_COL_GREEN); // hier ist noch x y vertauscht


// ************************************************************************************







  }	// end While(1)
// ************************************************************************************* 
}	// end main
// ************************************************************************************* 
// ************************************************************************************* 
// ************************************************************************************* 
// ************************************************************************************* 







