//--------------------------------------------------------------
// File     : stm32_ub_graphic.h
//--------------------------------------------------------------

//--------------------------------------------------------------
#ifndef __STM32F4_UB_GRAPHIC_H
#define __STM32F4_UB_GRAPHIC_H


//--------------------------------------------------------------
// Includes
//--------------------------------------------------------------
#include "stm32f4xx.h"
#include "stm32_ub_lcd_ssd1289.h"


//--------------------------------------------------------------
// Aktivieren, Deaktivieren von einer Funktion
// 1=aktiv, 0=inaktiv
//--------------------------------------------------------------
#define   GRAPHIC_USE_IMG     1   // Image-Funktionen
#define   GRAPHIC_USE_BMP     1   // Bmp-Funktionen
#define   GRAPHIC_USE_JPG     1   // Jpg-Funktionen





//--------------------------------------------------------------
// Struktur von einem Image
//--------------------------------------------------------------
typedef struct UB_Image_t
{
  const uint16_t *table; // Tabelle mit den Daten
  uint16_t width;        // Breite des Bildes (in Pixel)
  uint16_t height;       // Hoehe des Bildes  (in Pixel)
}UB_Image;



//--------------------------------------------------------------
// Struktur von einem Picture
//--------------------------------------------------------------
typedef struct UB_Picture_t
{
  const uint8_t *table; // Tabelle mit den Daten
  uint32_t size;        // Anzahl der Bytes
}UB_Picture;



//--------------------------------------------------------------
// Einbinden der benutzen Bilder
// fuer alle Bilder muss das entsprechende File
// auch in der CooCox-IDE hinzugefgt werden
//--------------------------------------------------------------
extern UB_Image Emo1_Image;
//extern UB_Image Emo2_Image;
//extern UB_Picture Emo1_Bmp;
extern UB_Picture Emo2_Bmp;
//extern UB_Picture Emo1_Jpg;
//extern UB_Picture Emo2_Jpg;




//--------------------------------------------------------------
// Struktur von einem Windows-BMP-File
//--------------------------------------------------------------
#if GRAPHIC_USE_BMP==1
typedef struct{
  uint32_t offset;
  uint32_t width;
  uint32_t height;
  uint16_t bpp;
  uint32_t compr;
  uint8_t spacer;
  uint32_t akt_ptr;
}GRAPHIC_BMP_t;
GRAPHIC_BMP_t GRAPHIC_BMP;
#endif


//--------------------------------------------------------------
// Return Werte beim zeichnen
//--------------------------------------------------------------
typedef enum {
  GRAPHIC_OK =0,
  GRAPHIC_FILE_ERR,
  GRAPHIC_SIZE_ERR,
  GRAPHIC_ID_ERR,
  GRAPHIC_HEAD_ERR,
  GRAPHIC_WIDTH_ERR,
  GRAPHIC_HEIGHT_ERR,
  GRAPHIC_BPP_ERR,
  GRAPHIC_COMPR_ERR
}GRAPHIC_ERR_t;


//--------------------------------------------------------------
// Typedef fr Windows-Jpg-File
//--------------------------------------------------------------
#if GRAPHIC_USE_JPG==1
typedef uint8_t       BYTE;
typedef uint16_t      WORD;
typedef uint32_t      DWORD;
#endif


//--------------------------------------------------------------
// Defines fr Windows-Jpg-File
//--------------------------------------------------------------
#if GRAPHIC_USE_JPG==1
#define M_SOF0  0xc0
#define M_DHT   0xc4
#define M_EOI   0xd9
#define M_SOS   0xda
#define M_DQT   0xdb
#define M_DRI   0xdd
#define M_APP0  0xe0

#define W1 2841  
#define W2 2676  
#define W3 2408  
#define W5 1609  
#define W6 1108  
#define W7 565   

#define MAKEWORD(a, b)      ((WORD)(((BYTE)(a)) | ((WORD)((BYTE)(b))) << 8))

#define FUNC_OK 0
#define FUNC_FORMAT_ERROR 3 
#endif


//--------------------------------------------------------------
// Struktur von einem Windows-Jpg-File
//--------------------------------------------------------------
#if GRAPHIC_USE_JPG==1
typedef struct{
  long CurX;
  long CurY;
  DWORD ImgWidth;
  DWORD ImgHeight; 
  short SampRate_Y_H;
  short SampRate_Y_V;
  short SampRate_U_H;
  short SampRate_U_V;
  short SampRate_V_H;
  short SampRate_V_V;
  short H_YtoU;
  short V_YtoU;
  short H_YtoV;
  short V_YtoV;
  short Y_in_MCU;
  short U_in_MCU;
  short V_in_MCU;  // notwendig ??
  unsigned char *lpJpegBuf;
  unsigned char *lp;
  short qt_table[3][64];
  short comp_num;
  BYTE comp_index[3];
  BYTE YDcIndex;
  BYTE YAcIndex;
  BYTE UVDcIndex;
  BYTE UVAcIndex;
  BYTE HufTabIndex;
  short *YQtTable;
  short *UQtTable;
  short *VQtTable;
  short code_pos_table[4][16];
  short code_len_table[4][16];
  unsigned short code_value_table[4][256];
  unsigned short huf_max_value[4][16];
  unsigned short huf_min_value[4][16];
  short BitPos;
  short CurByte;
  short rrun;
  short vvalue;
  short MCUBuffer[10*64];
  short QtZzMCUBuffer[10*64];
  short BlockBuffer[64];
  short ycoef;
  short ucoef;
  short vcoef;
  BYTE IntervalFlag;
  short interval;
  short Y[4*64];
  short U[4*64];
  short V[4*64];
  DWORD sizei;
  DWORD sizej;
  short restart;
  long iclip[1024];
  long *iclp;
}GRAPHIC_JPG_t;
GRAPHIC_JPG_t GRAPHIC_JPG;
#endif






//--------------------------------------------------------------
// Globale Funktionen
//--------------------------------------------------------------
void UB_Graphic_DrawPixel(int16_t xpos, int16_t ypos, uint16_t color);
void UB_Graphic_DrawLine(int16_t x1, int16_t y1, int16_t x2, int16_t y2, uint16_t color);
void UB_Graphic_DrawCircle(int16_t x0, int16_t y0, int16_t radius, uint16_t color);
#if GRAPHIC_USE_IMG==1
GRAPHIC_ERR_t UB_Graphic_DrawImage(UB_Image *img, int16_t xpos, int16_t ypos);
GRAPHIC_ERR_t UB_Graphic_DrawImageTransparent(UB_Image *img, int16_t xpos, int16_t ypos, uint16_t color);
#endif
#if GRAPHIC_USE_BMP==1
GRAPHIC_ERR_t UB_Graphic_DrawBmp(UB_Picture *bmp, uint16_t xpos, uint16_t ypos);
#endif
#if GRAPHIC_USE_JPG==1
GRAPHIC_ERR_t UB_Graphic_DrawJpg(UB_Picture *jpg, uint16_t xpos, uint16_t ypos);
#endif


//--------------------------------------------------------------
#endif // __STM32F4_UB_GRAPHIC_H
